%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 delta_MSB2.m
%                   Russell Luke
%               Department of MathSci
%              University of Delaware  
%                  April 12, 2008 
%
%
%
%
% DESCRIPTION:  TO DO
% 
%  Scaling for the MSB2 matrix
%
% INPUT:
%
%     S_mat, the matrix of steps
%     Y_mat, the matrix of gradient differences
%     alpha, a regularization parameter
%
% OUTPUT:
%        
%     delta... 
%
% USAGE: 
%
%       delta = delta_MSB2(S_mat, Y_mat, alpha)
% 
% SUBROUTINE CALLS:
%      none
%      

function [delta] = delta_MSB2(dim,mem,S_mat, Y_mat, alpha)
% normalize the columns of Y_mat for stability
ny=zeros(mem,1);
for j=1:mem
   ny(j)=1/norm(Y_mat(:,j));
end
Y_mat=Y_mat*diag(ny);
S_mat=S_mat*diag(ny);

% a quick way of estimating
%    delta = norm(S_mat*((Y_mat'*Y_mat+alpha_0*eye(mem,mem))\(Y_mat')));
% perform Rayleigh Quotient to estimate the norm of 
%    S_mat*((Y_mat'*Y_mat+alpha_0*eye(mem,mem))^{-1}(Y_mat')

% Look into doing a Cholesky factorization of Y'Y for stability
M_mat = ((Y_mat'*Y_mat+alpha*eye(mem,mem))\(Y_mat'));
rand('twister',5489) % sets the same seed for the same `random' vector
v0_vec              = rand(dim,1); % used to compute Rayleigh quotient
% v0_vec=ones(dim,1);

delta0 = 0;
delta  = 10;

RQ_iter=0;
v_vec = S_mat*(M_mat*v0_vec); 
while (abs((delta-delta0)/delta)>1e-5)&&(RQ_iter<10)
    RQ_iter=RQ_iter+1;
    v0_vec = v_vec/sqrt(v_vec'*v_vec);
    delta0=delta;
    v_vec = S_mat*(M_mat*v0_vec);    
    delta  = v0_vec'*v_vec;
end
delta = abs(delta);


