%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 invMSBAI_product.m
%                   Russell Luke
%  Department of MathSci, University of Delaware  
%                        and 
%  Inst. f. Num. u. Angew. Math., Universitaet Goettingen
%                    JUNE. 2, 2010  
%
%  This work was supported by NSF-DMS grant 0712796. 
%
%
% DESCRIPTION:  TO DO
% 
%  Stable inverse-BFGS matrix product
%
% INPUT:
%
%     K,mem: dimension variables
%     u_vec, the vector to be multiplied
%     S_mat, the matrix of steps
%     Y_mat, the matrix of gradient differences
%     del,   the initial scaling
%     alpha, a regularization parameter
%
% OUTPUT:
%        
%     v_vec = B^{-1}*u_vec, where B^{-1} is the BFGS matrix
%
% USAGE: 
%
%       v_vec = invBFGS1_product(K,mem,u_vec, S_mat, Y_mat, del, alpha)
% 
% SUBROUTINE CALLS:
%      none
%      

function v_vec = invMSBAI_product(K,mem,u_vec, S_mat, Y_mat, del, alpha)

% computes Hbar_S Eq(2.15) of MSBFGS.pdf
% below is a readable, but not efficient implementation
% STY_mat=S_mat'*Y_mat; % D^TG in paper
% YTY_mat=Y_mat'*Y_mat;% +1e-10*eye(size(STY_mat));
% v1_vec = YTY_mat\(Y_mat'*u_vec); % U^T*u_vec
% v2_vec = STY_mat*v1_vec; % (D^TG)U^T*u_vec
% v2_vec = Y_mat*(YTY_mat\v2_vec); % U(D^TG)U^T*u_vec
% v2T_vec = STY_mat'*v1_vec; % (D^TG)^T U^T*u_vec
% v2T_vec = Y_mat*(YTY_mat\v2T_vec); % U(D^TG)^T U^T*u_vec
% v3_vec = S_mat*v1_vec; % DU^T u_vec
% v3T_vec = S_mat'*u_vec;
% v3T_vec = Y_mat*(YTY_mat\v3T_vec); % UD^T u_vec
% v4_vec = u_vec - Y_mat*v1_vec;
% v4_vec = 10*del*(v4_vec - Y_mat*(YTY_mat\(Y_mat'*v4_vec))); %VH_0V^T u_vec

% v_vec = v4_vec + v3T_vec + v3_vec +(v2_vec); % + v2T_vec);
% next most important detail:  what is the correct del?
% then figure out the forward operator so that we can do a proper trust
% region.
STY_mat=S_mat'*Y_mat; % D^TG in paper
YTY_mat=Y_mat'*Y_mat;% +1e-10*eye(size(STY_mat));
U_mat=Y_mat*((YTY_mat+alpha*eye(mem))\eye(size(YTY_mat)));
% v_vec = V_mat*V_mat'*u_vec
v_vec = (u_vec - Y_mat*(U_mat'*u_vec));
v_vec = del*(v_vec - U_mat*(Y_mat'*v_vec));

v_vec = v_vec+U_mat*(S_mat'*u_vec);
v_vec = v_vec + S_mat*(U_mat'*u_vec);
v_vec = v_vec - U_mat*((STY_mat)*(U_mat'*u_vec)) ; 
% v_vec = v_vec - U_mat*(.5*(STY_mat+STY_mat')*(U_mat'*u_vec)) ; % taking the 
                                                               % symmetric
                                                               % projection
                                                               

