%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 invBFGS1_product.m
%                   Russell Luke
%                   Brian Rife
%               Department of MathSci
%              University of Delaware  
%                  April 12, 2008 
%
%
%
%
% DESCRIPTION:  TO DO
% 
%  Stable inverse-BFGS matrix product
%
% INPUT:
%
%     K,mem: dimension variables
%     u_vec, the vector to be multiplied
%     S_mat, the matrix of steps
%     Y_mat, the matrix of gradient differences
%     del,   the initial scaling
%     alpha, a regularization parameter
%
% OUTPUT:
%        
%     v_vec = B^{-1}*u_vec, where B^{-1} is the BFGS matrix
%
% USAGE: 
%
%       v_vec = invBFGS1_product(K,mem,u_vec, S_mat, Y_mat, del, alpha)
% 
% SUBROUTINE CALLS:
%      none
%      

function v_vec = invBFGS1_product(K,mem,u_vec, S_mat, Y_mat, del, alpha)

% below is a readable, but not efficient implementation
% STY_mat=S_mat'*Y_mat;
% D_mat=diag(diag(STY_mat));
% R_mat=inv(triu(STY_mat,0)); % bad style, but I do it this way for readability
% Phi_mat=[S_mat, (del)*Y_mat];
% Gam_mat=[R_mat'*(D_mat+(del)*Y_mat'*Y_mat)*R_mat, -R_mat'; -R_mat, zeros(size(STY_mat))];
% v0_vec = Phi_mat*Gam_mat*Phi_mat'*u_vec;
% v_vec = (del)*u_vec+v0_vec;

% the way it SHOULD be done:
STY_mat=S_mat'*Y_mat;
D_mat=diag(diag(STY_mat));
R_mat=(triu(STY_mat+1e-11*eye(size(STY_mat)),0));
Rt_mat=R_mat';
% the above regularization is expedient, but would like 
% to implement a cholesky factorization.

v1_vec = S_mat'*u_vec;
v2_vec = (del)*Y_mat'*u_vec;
v3_vec = R_mat\v1_vec;
v3_vec = ((D_mat+(del)*Y_mat'*Y_mat)*v3_vec) - v2_vec;
v3_vec = Rt_mat\v3_vec;
v2_vec = -R_mat\v1_vec;
v_vec  = (del)*u_vec + S_mat*v3_vec + (del)*Y_mat*v2_vec;





