%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    J_gradJ.m
%                   Russell Luke
%             Department of MathSci
%              University of Delaware  
%                    Oct 3, 2007 
% 
%    INPUT: 
%           params, a structure file
%           x, a matrix
%
%    OUTPUT:
%           J, a scalar function value
%          gradJ, the gradient of J, a vector
%
%      USAGE: 
%            [J, gradJ]=J_gradJ(params,x)
%
function [J, gradJ]=J_gradJ(params,x)

dim=params.dim;
im=sqrt(-1);
epsilon=1e-14;
scalesq=1/(dim(1)*dim(2));
P=complex(zeros(dim(1),dim(2),dim(3)));
K=complex(zeros(dim(1),dim(2),dim(3)));
R=complex(zeros(dim(1),dim(2),1+dim(3)));
J=zeros(1+dim(3),1);
gradJ = zeros(dim(1),dim(2),2);

temp=feval('reshape',x,dim(1),2*dim(2));
x=zeros(dim(1),dim(2),2);
x(:,:,1)=temp(:,1:dim(2));
x(:,:,2)=temp(:,dim(2)+1:2*dim(2));

% ======== Pupil Plane =========
% R(:,:,1) = (x(:,:,1).*x(:,:,1)+x(:,:,2).*x(:,:,2)).^(.5)-Xi_A;
temp= x(:,:,1).*x(:,:,1)+x(:,:,2).*x(:,:,2);
R(:,:,1)=temp./((temp+epsilon).^(.5))-params.Xi_A;
% R(:,:,1) = (x(:,:,1).*x(:,:,1)+x(:,:,2).*x(:,:,2))-Xi_A;
J(1)=sum(sum(R(:,:,1).*R(:,:,1)));

% ======== Image plane =========
for j=1:dim(3)

    P(:,:,j)=feval('FFT',...
        (x(:,:,1)+im*x(:,:,2)).*params.Xi_A.*exp(im*params.aberration(:,:,j)));
    % actually P^
    K(:,:,j)=real(P(:,:,j).*conj(P(:,:,j))); % technically
    % K(-^).^(.5)
    % I'm working with k^(.5) here.
    R(:,:,j+1)=K(:,:,j)./((K(:,:,j)+epsilon).^(.5))-params.k(:,:,j);
    J(1+j) = feval('sum',feval('sum',R(:,:,j+1).*R(:,:,j+1)));
end
J=.5*sum(J);%*scalesq;

% ============end function evaluations==============

% ==========================
% =  compute the gradient  =
% ==========================

% ========== pupil plane ===========
% temp=((R(:,:,1)+Xi_A)./(temp+epsilon)).*(1+2*epsilon./temp);
temp= (temp+2*epsilon)./((temp+epsilon).^(1.5));
gradJ(:,:,1)=(R(:,:,1).*(x(:,:,1).*temp));
gradJ(:,:,2)=(R(:,:,1).*(x(:,:,2).*temp));

% ========== Image plane ===========
tempu=complex(zeros(dim(1),dim(2)));
for j=1:dim(3)
    temp=(K(:,:,j)+2*epsilon)./((K(:,:,j)+epsilon).^(1.5));
    tempu=tempu+(params.Xi_A.*exp(-im*params.aberration(:,:,j)).*...
        feval('IFFT',R(:,:,j+1).*(P(:,:,j).*temp)));
end
gradJ(:,:,1)=(gradJ(:,:,1)+real(tempu))*scalesq;
gradJ(:,:,2)=(gradJ(:,:,2)+imag(tempu))*scalesq;
clear tempu 

% =========end gradient calculations=========
temp(1:dim(1),1:dim(2))= gradJ(:,:,1);
temp(1:dim(1),dim(2)+1:2*dim(2))= gradJ(:,:,2);
gradJ=feval('reshape',temp,dim(1)*2*dim(2),1);


clear R P K temp
clear params x

