%###########################################################
%            OPTIONS_opt_choices
%	     Patrick C. Rowe
%	      Marco Bedolla
%	  Department of MathSci	        
%	  University of Delaware
%             June 10, 2009
%       
%  This work was supported by NSF-DMS grant 0712796. 
%
% This file is designed to be manipulated by the user to communicate
% with the SAMSARA package. Any line beginning with an % is not read
% by the SAMSARA package. The use is as follows.
%
% The first four lines without exclamation points communicate with
% the SAMSARA package. The lines must be in the order
%
%  1. Hessian approximation method
%  2. History ordering method
%  3. Trust region adjustment method
%  4. Dimension of the space 
% 
% 
%###########################################################
%
% Hessian_Method
% Quasi-Newton methods for estimation of the function's Hessian.
% Broyden implementations use Dogleg_QN lin search methods
% while BFGS implementations use Explicit_TR.
%
% To choose a method, simply put an exclamation point in front
% of the current method and delete the exclamation point in front
% of the desired method. 
% 
% 
QN_method = 'BFGS1';

% Other methods availabel:
%  'MSBroyden1'
%  'MSBroyden2';
%  'Broyden1'
%  'Broyden2'
%  'MSBAI'
%  'BFGS1'
%
%###########################################################
% 
% History
% Ordering methods for S, Y matrices in limited memory application.
% Finite difference ordering, fdSY_mat, is recommended for Broyden 
% implementations. For BFGS implementations, use conjugate
% direction ordering, cdSY_mat.
%
% To choose a method, simply put an exclamation point in front
% of the current method and delete the excalamation point in front
% of the desired method. 
%
%
% 
History = 'cdSY_mat'; % or 'fdSY_mat'
%
%
%###########################################################
%
% Trust Region Adjust
% Select the method used for adjustment of the trust region 
% in optimization.
%
% To choose a method, simply put an exclamation point in front
% of the current method and delete the excalamation point in front
% of the desired method.
%
%
update_conditions = 'Trust Region'; % or 'Exact'
%
%###########################################################
% 
% Initial Step Scaler
% The norm of the initial step taken in the Cauchy direction.
% This multiplied against the normalized gradient to yield the
% initial direction vector in order to generate the first step
% taken by SAMSARA.
% 
% Assign a value of 0.0D0 to use the default value which is the
% minimum of 1D-1 or the norm(1d-1*gradient).
%    
initial_step = 1e+5*step_TOL;