function [f,gf] = NDRosenbrock(x,param)

[n,m]=size(x);
if(nargin<2)
    % the default is a randomly generated Rosenbrock function
    % of dimension length(x) whose optimal solution is at x=1
    rand('twister',17); % sets the seed to the default
    q     = rand(n,n-1)-0.5;
    Q     = q*q';
    b     = 100*rand(n,1);
    b     = b-q*((q'*q)\(q'*b));
    b     = -b/sum(b);
    x_opt = ones(n,1);
    a     = -2*Q*x_opt;
    alpha = 100*sign(a'* x_opt +x_opt'*Q*x_opt)/(a'* x_opt +x_opt'*Q*x_opt)^2; 
    % the smaller alpha, the more skewed the optimal neighborhood
    beta  = 1;
    % the larger beta, the more skewed the optimal neighborhood
else
    Q     = param.Q;
    a     = param.a;
    b     = param.b;
    alpha = param.alpha;
    beta  = param.beta;
end
 f = (alpha*(a'*x + diag(x'*Q*x)').^2 + beta*(1 + b'*x).^2);
 if(nargout==2)
     gf = (2*alpha*(a'*x + x'*Q*x)*(a + 2*Q'*x) + 2*beta*(1+b'*x)*b);
 end
